Index: public/web/WebNavigatorContentUtilsClient.h |
diff --git a/public/web/WebPageVisibilityState.h b/public/web/WebNavigatorContentUtilsClient.h |
similarity index 82% |
copy from public/web/WebPageVisibilityState.h |
copy to public/web/WebNavigatorContentUtilsClient.h |
index fe02afd42d3c962943ab58e9346e3727b9b218a7..17350bb46d511e967e5b303c1cc2df75a49cd4c6 100644 |
--- a/public/web/WebPageVisibilityState.h |
+++ b/public/web/WebNavigatorContentUtilsClient.h |
@@ -1,5 +1,5 @@ |
/* |
- * Copyright (C) 2011 Google Inc. All rights reserved. |
+ * Copyright (C) 2014, Samsung Electronics. All rights reserved. |
* |
* Redistribution and use in source and binary forms, with or without |
* modification, are permitted provided that the following conditions are |
@@ -28,17 +28,17 @@ |
* OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE. |
*/ |
-#ifndef WebPageVisibilityState_h |
-#define WebPageVisibilityState_h |
+#ifndef WebNavigatorContentUtilsClient_h |
+#define WebNavigatorContentUtilsClient_h |
namespace blink { |
// The following enum should be consistent with the PageVisibilityState enum |
// defined in WebCore. |
-enum WebPageVisibilityState { |
- WebPageVisibilityStateVisible, |
- WebPageVisibilityStateHidden, |
- WebPageVisibilityStatePrerender, |
+enum WebCustomHandlersState { |
+ WebCustomHandlersNew, |
+ WebCustomHandlersRegistered, |
+ WebCustomHandlersDeclined |
}; |
} // namespace blink |
@@ -28,17 +28,17 @@ |
namespace blink { |
-// The following enum should be consistent with the PageVisibilityState enum |
+// The following enum should be consistent with the CustomHandlersState enum |
// defined in WebCore. |